﻿Imports System.IO
Imports System.Drawing.Imaging

Public Class frmMain
    Dim TempFile As String = Path.Combine(Application.StartupPath, "temp0.bmp")
    'Dialog filter
    Private Const fFilter As String = "GIF Files(*.gif)|*.gif"

    Private Sub lstFrames_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles lstFrames.SelectedIndexChanged
        Dim fd As New FrameDimension(TheImage.FrameDimensionsList(0))

        'Set the image to extract.
        TheImage.SelectActiveFrame(fd, lstFrames.SelectedIndex)
        'Display the image.
        PicFrame.Image = New Bitmap(TheImage)

        'Tidy up
        fd = Nothing

    End Sub

    Private Sub cmdOpen_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdOpen.Click
        Dim od As New OpenFileDialog()
        Dim guid As Object = Nothing
        Dim fTitle As String = vbNullString

        od.Title = "Open"
        od.Filter = fFilter

        If (od.ShowDialog() = DialogResult.OK) Then
            'Clear listbox.
            lstFrames.Items.Clear()
            'Clear picture.
            PicFrame.Image = Nothing
            'Load image.
            TheImage = Image.FromFile(od.FileName)
            'Get file info
            Dim fInfo As New FileInfo(od.FileName)
            'Get position of last .
            Dim sPos As Integer = fInfo.Name.LastIndexOf(".")

            If (sPos.Equals(-1)) Then
                fTitle = fInfo.Name
            Else
                'Extract file title
                fTitle = fInfo.Name.Substring(0, sPos)
            End If

            'Get FrameDimensionsList.
            guid = TheImage.FrameDimensionsList

            If Array.IndexOf(guid, FrameDimension.Time.Guid).Equals(-1) Then
                MessageBox.Show("Unable to read file.", Text, MessageBoxButtons.OK, MessageBoxIcon.Warning)
            Else
                'Display picture in PicViewer
                PicViewer.Image = TheImage
                'Get number of frames.
                Dim Frames As Integer = TheImage.GetFrameCount(FrameDimension.Time)
                'Update label.
                lblFilename.Text = fInfo.FullName & " | Frames: " & Frames - 1
                'Add frames names to listbox.
                For Counter As Integer = 0 To Frames - 1
                    'Use file name as frame names.
                    lstFrames.Items.Add(fTitle & Counter.ToString())
                Next
                'Select first frame.
                If (lstFrames.Items.Count > 0) Then
                    lstFrames.SetSelected(0, True)
                End If
            End If
        End If

        od = Nothing
    End Sub

    Private Sub cmdAbout_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdAbout.Click
        'Show about
        MessageBox.Show(Text & " v1.1" & vbCrLf & vbTab & "By Ben Jones", "About...", MessageBoxButtons.OK, MessageBoxIcon.Information)
    End Sub

    Private Sub cmdClose_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdClose.Click
        'Close prog
        Close()
    End Sub

    Private Sub sTab_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles sTab.SelectedIndexChanged
        'Enable / disable items.
        lstFrames.Enabled = sTab.SelectedIndex.Equals(0)

        cmdSave.Enabled = lstFrames.Enabled
        cmdSaveAll.Enabled = lstFrames.Enabled
        cmdCopy.Enabled = lstFrames.Enabled
        cmdEdit.Enabled = lstFrames.Enabled
    End Sub

    Private Sub cmdSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdSave.Click
        Dim sd As New SaveFileDialog()

        sd.Title = "Save"
        sd.Filter = "Bitmap Files(*.bmp)|*.bmp|GIF Files(*.gif)|*.gif|PNG Files(*.png)|*.png|JPEG Files(*.jpg;*.jpg)|*.jpeg;*.jpg"
        sd.FileName = lstFrames.Text

        If (lstFrames.SelectedIndex.Equals(-1)) Then
            Exit Sub
        Else
            If (sd.ShowDialog() = DialogResult.OK) Then
                'Save selected frame.
                Select Case sd.FilterIndex
                    Case 1
                        'Save Bitmap
                        PicFrame.Image.Save(sd.FileName, ImageFormat.Bmp)
                    Case 2
                        'Save Gif
                        PicFrame.Image.Save(sd.FileName, ImageFormat.Gif)
                    Case 3
                        'Save png
                        PicFrame.Image.Save(sd.FileName, ImageFormat.Png)
                    Case 4
                        'Save jpeg
                        PicFrame.Image.Save(sd.FileName, ImageFormat.Jpeg)
                End Select
            End If
        End If
    End Sub

    Private Sub cmdSaveAll_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdSaveAll.Click
        Dim frm As New frmSave()

        If (lstFrames.Items.Count > 0) Then
            'Show dialog
            frm.ShowDialog()
        End If

    End Sub

    Private Sub cmdEdit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdEdit.Click
        If (lstFrames.SelectedIndex.Equals(-1)) Then
            Exit Sub
        Else
            'Open frame in mspaint editor.
            Dim p As New System.Diagnostics.Process
            'Save copy of the image
            PicFrame.Image.Save(TempFile, Imaging.ImageFormat.Bmp)
            'Set parms.
            p.StartInfo.FileName = "mspaint"
            p.StartInfo.Arguments = TempFile
            Try
                'Start process
                p.Start()
            Catch ex As Exception
                MessageBox.Show(ex.Message, Text, MessageBoxButtons.OK, MessageBoxIcon.Error)
            End Try
        End If
    End Sub

    Private Sub frmMain_FormClosing(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles MyBase.FormClosing
        'Remove temp image
        If File.Exists(TempFile) Then
            Try
                File.Delete(TempFile)
            Catch ex As Exception

            End Try
        End If
    End Sub

    Private Sub cmdCopy_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdCopy.Click
        If (lstFrames.SelectedIndex.Equals(-1)) Then
            Exit Sub
        Else
            'Copy selected frame to clipboard.
            Clipboard.SetData(DataFormats.Bitmap, PicFrame.Image)
        End If
    End Sub

    Private Sub frmMain_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        lblFilename.Text = vbNullString
    End Sub
End Class
